"""提供库打包精简配置功能"""

import dataclasses
import typing

__all__ = [
    "get_simplify_options",
]


@dataclasses.dataclass
class SimplifierOption:
    """库简化打包配置"""

    # 白名单匹配规则
    patterns: typing.Optional[typing.Set[str]] = None

    # 黑名单匹配规则
    excludes: typing.Optional[typing.Set[str]] = None


# 简化配置
__simplifier_options_dict: typing.Dict[str, SimplifierOption] = dict(
    pyside2=SimplifierOption(
        patterns={
            "PySide2/__init__.py",
            "PySide2/pyside2.abi3.dll",
            "PySide2/QtCore.pyd",
            "PySide2/Qt5Core.dll",
            "PySide2/QtGui.pyd",
            "PySide2/Qt5Gui.dll",
            "PySide2/QtWidgets.pyd",
            "PySide2/Qt5Widgets.dll",
            "PySide2/QtNetwork.pyd",
            "PySide2/Qt5Network.dll",
            "PySide2/QtQml.pyd",
            "PySide2/Qt5Qml.dll",
            "*plugins/iconengines/qsvgicon.dll",
            "*plugins/imageformats/*.dll",
            "*plugins/platforms/*.dll",
        },
    ),
    pygame=SimplifierOption(
        excludes={
            "pygame/docs/*",
            "pygame/examples/*",
            "pygame/tests/*",
            "pygame/__pyinstaller/*",
            "pygame*data/*",
        }
    ),
    matplotlib=SimplifierOption(
        excludes={"matplotlib-.*.pth"},
        patterns={
            "matplotlib/*",
            "matplotlib.libs/*",
            "mpl_toolkits/*",
            "pylab.py",
        },
    ),
    numba=SimplifierOption(
        patterns={
            "numba/*",
            "numba*data/*",
        }
    ),
    numpy=SimplifierOption(
        excludes={
            "numpy/_pyinstaller/*",
            "numpy/tests/*",
        }
    ),
    torch=SimplifierOption(
        excludes={
            # for debug
            "torch/utils/bottleneck/*",
            "torch/utils/checkpoint/*",
            "torch/utils/tensorboard/*",
            # for test
            "torch/utils/data/dataset/*",
            "torch/utils/data/dataloader/*",
        }
    ),
)


def get_simplify_options(name: str) -> SimplifierOption:
    global __simplifier_options_dict

    return __simplifier_options_dict.get(name, None)
